Requirements

## 1.1 Requirements

1. As a standalone application.

   `NanoCap` is built into a DMG for OSX and an .EXE for Windows. The required libraries listed below are bundled but not modified in line with the associated licenses.

   OSX: `NanoCap` works straight out of the box simply extract the application from the DMG and drag it into the Applications folder.

   Windows: `NanoCap` requires the Microsoft Visual C++ 2008 Redistributable Package which can be obtained from:

   http://www.microsoft.com/en-au/download/details.aspx?id=29

2. From source without rendering/GUI capabilities

   - NumPy - Version 1.6.2

   - Scipy - Version 0.11.0

   - sqlite3 Version 2.6.0 (bundled with Python)

   - C compiler (e.g. GCC)

   - Fortran compiler (e.g. GFortran)

3. From source with rendering/GUI capabilities

   - Qt - Version 4.8.5

   - PySide - Version 1.1.1 (depends on Qt)

   - VTK - Version 5.8 (+ Python Wrappers)

Installation of the dependencies above is platform specific and there are multiple methods of achieving the required python working environment. The simplest options are using package managers or binary distributions, i.e:
OSX:

- Homebrew http://brew.sh

- MacPorts http://www.macports.org

- Fink http://www.finkproject.org/

Windows:

- PythonXY http://code.google.com/p/pythonxy

- Enthought Python http://www.enthought.com/products/epd

Linux:

- apt-get

- YUM (RPM Package Manager)